/*
    SPDX-FileCopyrightText: 2016 Kai Uwe Broulik <kde@privat.broulik.de>
    SPDX-FileCopyrightText: 2016 Marco Martin <mart@kde.org>
    SPDX-FileCopyrightText: 2024 Slava Aseev <nullptrnine@basealt.ru>

    SPDX-License-Identifier: GPL-2.0-or-later
*/

import QtQuick 2.15
import QtGraphicalEffects 1.15

import org.kde.plasma.components 3.0 as PlasmaComponents3
import org.kde.plasma.core 2.1 as PlasmaCore

import org.kde.plasma.plasmoid 2.0

Rectangle {
    property alias text: label.text
    property Item icon

    readonly property bool showBackground: Plasmoid.configuration.showBackgroundOnTempBadge

    color: showBackground ? PlasmaCore.ColorScope.backgroundColor : "transparent"
    width: Math.max(PlasmaCore.Units.gridUnit, label.width + PlasmaCore.Units.devicePixelRatio * 2)
    height: label.height
    radius: PlasmaCore.Units.devicePixelRatio * 3
    opacity: showBackground ? 0.9 : 1

    PlasmaComponents3.Label {
        id: label
        anchors.centerIn: parent
        font.pixelSize: Math.max(icon.height / 4, PlasmaCore.Theme.smallestFont.pixelSize * (Plasmoid.configuration.tempBadgeScale * 0.01))
    }

    DropShadow {
        id: textShadow
        visible: main.isDark(PlasmaCore.ColorScope.backgroundColor, 0.65)

        anchors.fill: label
        radius: 4
        samples: 9
        spread: 0.5
        color: "black"
        source: label
    }

    layer.enabled: showBackground
    layer.effect: DropShadow {
        horizontalOffset: 0
        verticalOffset: 0
        radius: PlasmaCore.Units.devicePixelRatio * 2
        samples: radius * 2
        color: Qt.rgba(0, 0, 0, 0.5)
    }
}
