/*
 * SPDX-FileCopyrightText: 2024 Slava Aseev <nullptrnine@basealt.ru>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

import QtQuick 2.15
import QtQuick.Layouts 1.15
import QtQuick.Controls 2.3 as QQC

import org.kde.plasma.plasmoid 2.0
import org.kde.plasma.core 2.0 as PlasmaCore
import org.kde.plasma.extras 2.0 as PlasmaExtras
import org.kde.plasma.components 3.0 as PlasmaComponents
import org.kde.plasma.alt.private.weather 1.0

ColumnLayout {
    id: root

    Item {
        Layout.fillWidth: true
        Layout.fillHeight: true

        function shouldBeVisible() {
            return main.status === Util.NeedToConfigure
                || main.status === Util.Connecting
                || main.status === Util.Timeout
                || main.status === Util.Error;
        }

        Layout.minimumWidth: shouldBeVisible() ? Math.max(PlasmaCore.Units.gridUnit, 18) * 24 : 0
        Layout.minimumHeight: shouldBeVisible() ? Math.max(PlasmaCore.Units.gridUnit, 18) * 26 : 0

        visible: shouldBeVisible()

        PlasmaExtras.PlaceholderMessage {
            anchors.centerIn: parent

            visible: main.status === Util.NeedToConfigure
            iconName: "mark-location"
            text: i18n("Please set your location")

            helpfulAction: QQC.Action {
                icon.name: "configure"
                text: i18n("Set location…")
                onTriggered: {
                    Plasmoid.action("configure").trigger();
                }
            }
        }

        PlasmaExtras.PlaceholderMessage {
            id: disconnectMessage

            anchors.centerIn: parent

            visible: main.status === Util.Timeout || main.status === Util.Error
            iconName: "network-disconnect"
            text: main.getErrorText()
        }

        QQC.BusyIndicator {
            anchors.centerIn: parent

            width: PlasmaCore.Units.iconSizes.enormous
            height: PlasmaCore.Units.iconSizes.enormous

            running: main.status === Util.Connecting
            visible: main.status === Util.Connecting
        }
    }

    ColumnLayout {
        id: contentLayout

        spacing: main.isInSystemTray ? PlasmaCore.Units.smallSpacing : PlasmaCore.Units.largeSpacing
        Layout.margins: PlasmaCore.Units.mediumSpacing

        visible: main.status === Util.Normal || main.status === Util.Emergency

        DetailsView {}

        PlasmaComponents.TabBar {
            id: tabBar

            Layout.fillWidth: true

            PlasmaComponents.TabButton {
                id: forecastHourButton
                text: i18nc("@title:tab", "Hourly")
            }

            PlasmaComponents.TabButton {
                id: forecastWeekButton
                text: i18nc("@title:tab", "Daily")
            }
        }

        QQC.SwipeView {
            id: swipeView

            Layout.fillWidth: true
            Layout.fillHeight: true
            Layout.alignment: Qt.AlignVCenter | Qt.AlignHCenter
            Layout.minimumWidth: Math.max(forecastWeekView.Layout.minimumWidth, forecastHourView.Layout.minimumWidth)
            Layout.minimumHeight: Math.max(forecastWeekView.Layout.minimumHeight, forecastHourView.Layout.minimumHeight)

            clip: true
            currentIndex: tabBar.currentIndex

            ColumnLayout {
                Layout.fillWidth: true

                ForecastView {
                    id: forecastHourView

                    Layout.alignment: Qt.AlignCenter
                    Layout.fillWidth: true
                    isHourly: true
                }
            }

            ColumnLayout {
                Layout.fillWidth: true

                ForecastView {
                    id: forecastWeekView

                    Layout.alignment: Qt.AlignCenter
                    Layout.fillWidth: true
                    isHourly: false
                }
            }

            onCurrentIndexChanged: {
                tabBar.setCurrentIndex(currentIndex);
            }
        }

        YandexLogo {}
    }
}
