/*
 * SPDX-FileCopyrightText: 2024 Slava Aseev <nullptrnine@basealt.ru>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

import QtQuick 2.15
import QtQuick.Layouts 1.15

import org.kde.plasma.core 2.0 as PlasmaCore
import org.kde.plasma.components 3.0 as PlasmaComponents
import org.kde.plasma.extras 2.0 as PlasmaExtras


RowLayout {
    id: root

    property alias model: repeater.model
    property bool isHourly: false

    Layout.alignment: Qt.AlignVCenter
    Layout.fillWidth: true

    spacing: isHourly ? PlasmaCore.Units.mediumSpacing : PlasmaCore.Units.smallSpacing

    Repeater {
        id: repeater
        model: isHourly ? main.forecastHourModel : main.forecastWeekModel

        delegate: ColumnLayout {
            id: dayDelegate

            readonly property int preferredIconSize: PlasmaCore.Units.iconSizes.large
            readonly property int hAlignment: Qt.AlignHCenter

            spacing: Math.max(4, PlasmaCore.Units.smallSpacing)

            readonly property var dayTempLabelWidth: dayTempLabel.width

            readonly property var prefWidth: {
                return Math.max(
                    preferredIconSize,
                    dayTempLabel.width,
                    index == 0 ? 0 : repeater.itemAt(0).dayTempLabelWidth,
                ) * 1.2
            }

            Layout.fillWidth: true
            Layout.minimumWidth: prefWidth

            PlasmaExtras.Heading {
                id: periodLabel

                Layout.alignment: Qt.AlignBottom | hAlignment
                horizontalAlignment: Qt.AlignHCenter
                Layout.fillWidth: true

                visible: !isHourly
                text: {
                    if (!isHourly) {
                        return modelData.currentDate ? i18nc("@label", "Today") : modelData.dayOfWeek;
                    }
                    return ""
                }
                level: 3
                type: PlasmaExtras.Heading.Type.Normal
            }

            PlasmaComponents.Label {
                id: dayLabel

                Layout.fillWidth: true
                Layout.alignment: Qt.AlignTop | hAlignment
                horizontalAlignment: Qt.AlignHCenter
                text: isHourly ? modelData.hour : modelData.dayOfMonth
            }

            PlasmaCore.IconItem {
                Layout.fillWidth: true
                Layout.preferredHeight: preferredIconSize
                Layout.preferredWidth: preferredIconSize
                Layout.alignment: Qt.AlignVCenter | hAlignment

                source: modelData.icon

                PlasmaCore.ToolTipArea {
                    id: iconToolTip
                    anchors.fill: parent
                    mainText: main.getWeatherDescription(modelData.condition)
                }
            }

            PlasmaExtras.Heading {
                id: dayTempLabel

                Layout.alignment: Qt.AlignVCenter | hAlignment
                horizontalAlignment: Qt.AlignHCenter

                text: {
                    if (isHourly) {
                        return modelData.temp;
                    }
                    if (modelData.currentDate) {
                        return i18nc("@label", "day %1", modelData.dayTemp);
                    }
                    return modelData.dayTemp;
                }

                level: 3
                type: PlasmaExtras.Heading.Type.Normal
            }

            PlasmaExtras.Heading {
                visible: !isHourly

                Layout.fillWidth: true
                Layout.alignment: Qt.AlignVCenter | hAlignment
                horizontalAlignment: Text.AlignHCenter
                text: (modelData.currentDate ? i18nc("@label", "night") : "") + " " + modelData.nightTemp

                level: 5
                type: PlasmaExtras.Heading.Type.Secondary
            }
        }
    }
}
