/*
 * SPDX-FileCopyrightText: 2018 Friedrich W. H. Kossebau <kossebau@kde.org>
 * SPDX-FileCopyrightText: 2023 Slava Aseev <nullptrnine@basealt.ru>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

import QtQuick 2.9

import QtQuick.Layouts 1.3

import org.kde.plasma.core 2.0 as PlasmaCore
import org.kde.plasma.components 3.0 as PlasmaComponents

RowLayout {
    id: iconAndTextRoot

    property alias iconSource: icon.source
    property alias text: label.text
    property alias active: icon.active

    readonly property int minimumIconSize: PlasmaCore.Units.iconSizes.small
    readonly property int iconSize: height
    readonly property int minWidth: (icon.width + text.width)

    spacing: 0

    PlasmaCore.IconItem {
        id: icon

        readonly property int implicitMinimumIconSize: Math.max(iconSize, minimumIconSize)
        // reset implicit size, so layout in free dimension does not stop at the default one
        implicitWidth: minimumIconSize
        implicitHeight: minimumIconSize

        Layout.fillWidth: false
        Layout.fillHeight: true
        Layout.minimumWidth: implicitMinimumIconSize
        Layout.minimumHeight: minimumIconSize

        roundToIconSize: false
    }

    Item {
        id: text

        Layout.alignment: Qt.AlignLeft
        // Otherwise it takes up too much space while loading
        visible: label.text.length > 0

        Layout.fillWidth: false
        Layout.fillHeight: true
        Layout.minimumWidth: sizehelper.paintedWidth
        Layout.maximumWidth: Layout.minimumWidth

        Layout.minimumHeight: 0
        Layout.maximumHeight: Infinity

        Text {
            id: sizehelper

            font {
                family: label.font.family
                weight: label.font.weight
                italic: label.font.italic
                pixelSize: 1024
            }
            minimumPixelSize: PlasmaCore.Theme.mSize(PlasmaCore.Theme.smallestFont).height / 2
            fontSizeMode: Text.VerticalFit
            wrapMode: Text.NoWrap

            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            anchors {
                leftMargin: PlasmaCore.Units.smallSpacing
                rightMargin: PlasmaCore.Units.smallSpacing
            }
            // These magic values are taken from the digital clock, so that the
            // text sizes here are identical with various clock text sizes
            height: {
                const textHeightScaleFactor = (parent.height > 26) ? 0.7 : 0.9;
                return Math.min (parent.height * textHeightScaleFactor, 10 * PlasmaCore.Theme.defaultFont.pixelSize);
            }
            visible: false

            // pattern to reserve some constant space TODO: improve and take formatting/i18n into account
            text: "888° X"
        }

        PlasmaComponents.Label {
            id: label

            font {
                weight: Font.Normal
                pixelSize: 1024
                pointSize: 0 // we need to unset pointSize otherwise it breaks the Text.Fit size mode
            }
            minimumPixelSize: PlasmaCore.Theme.mSize(PlasmaCore.Theme.smallestFont).height / 2
            fontSizeMode: Text.Fit
            wrapMode: Text.NoWrap

            height: 0
            width: 0

            verticalAlignment: Text.AlignVCenter
            horizontalAlignment: Text.AlignHCenter

            anchors {
                fill: parent
                leftMargin: PlasmaCore.Units.smallSpacing
                rightMargin: PlasmaCore.Units.smallSpacing
            }
        }
    }
}
