/*
 * SPDX-FileCopyrightText: 2024 Slava Aseev <nullptrnine@basealt.ru>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

import QtQuick 2.15
import QtQuick.Layouts 1.15
import QtQuick.Controls 2.3 as QQC

import org.kde.plasma.plasmoid 2.0
import org.kde.plasma.core 2.0 as PlasmaCore
import org.kde.plasma.workspace.components 2.0 as WorkspaceComponents
import org.kde.plasma.alt.private.weather 1.0

Item {
    id: trayRoot
    anchors.fill: parent

    readonly property bool useBadge: Plasmoid.formFactor == PlasmaCore.Types.Vertical || main.isInSystemTray

    readonly property var iconSource: {
        if (main.status === Util.NeedToConfigure) {
            return "mark-location";
        }
        else if (main.status === Util.Timeout || main.status === Util.Error) {
            return "network-disconnect";
        }
        return main.factModel.icon;
    }

    readonly property var textInfo: {
        if (main.status === Util.NeedToConfigure) {
            return useBadge ? "?" : i18n("Setup…");
        }
        else if (main.status === Util.Timeout || main.status === Util.Error) {
            return useBadge ? "?" : i18n("Error!");
        }
        return main.factModel.temp;
    }

    Layout.minimumWidth: Math.max(iconAndTextItem.minWidth, busy.width)

    QQC.BusyIndicator {
        id: busy

        implicitWidth: PlasmaCore.Units.gridUnit
        implicitHeight: PlasmaCore.Units.gridUnit

        anchors.centerIn: parent
        running: main.status === Util.Connecting
        visible: main.status === Util.Connecting
    }

    IconAndTextItem {
        id: iconAndTextItem

        anchors.fill: parent
        iconSource: trayRoot.iconSource
        text: trayRoot.textInfo
        visible: !useBadge && main.status !== Util.Connecting
    }

    PlasmaCore.IconItem {
        id: iconItem

        source: trayRoot.iconSource
        visible: useBadge && main.status !== Util.Connecting

        anchors.fill: parent
        roundToIconSize: false

        BadgeOverlay {
            anchors.bottom: parent.bottom
            anchors.right: parent.right

            visible: useBadge && main.status !== Util.Connecting

            text: trayRoot.textInfo
            icon: parent
        }
    }

    MouseArea {
        id: mouseArea

        anchors.fill: parent
        hoverEnabled: true
        onClicked: {
            Plasmoid.expanded = !Plasmoid.expanded
        }
    }
}
