/*
 * SPDX-FileCopyrightText: 2024 Slava Aseev <nullptrnine@basealt.ru>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

import QtQuick 2.15
import QtQuick.Layouts 1.15

import org.kde.plasma.core 2.0 as PlasmaCore
import org.kde.plasma.components 3.0 as PlasmaComponents

Repeater {
    RowLayout {
        spacing: PlasmaCore.Units.smallSpacing

        PlasmaCore.IconItem {
            Layout.preferredWidth: PlasmaCore.Units.iconSizes.smallMedium
            Layout.preferredHeight: PlasmaCore.Units.iconSizes.smallMedium
            source: main.iconName(modelData[0])
        }

        PlasmaComponents.Label {
            id: windLabel
            text: {
                if (modelData[0] == "ic_wind") {
                    var str = "";
                    if (main.factModel.windDir != 'c') {
                        str += modelData[1] + ", ";
                    }
                    str += main.windDirPrettify(main.factModel.windDir);
                    return str;
                }
                else {
                    return modelData[1];
                }
            }
        }

        PlasmaCore.IconItem {
            id: windDirIcon

            readonly property var prefSize: PlasmaCore.Units.iconSizes.small * 0.8

            Layout.preferredWidth: prefSize
            Layout.preferredHeight: prefSize
            Layout.alignment: Qt.AlignCenter

            /* Show only if wind dir is not 'calm' */
            visible: modelData[0] == "ic_wind" && main.factModel.windDir != 'c'
            source: main.iconName("wind_dir")
            roundToIconSize: false

            transform: Rotation {
                origin { x: windDirIcon.width / 2;
                         y: windDirIcon.height / 2;
                         z: 0}
                angle: main.windDirIconAngle(main.factModel.windDir) ?? 0
            }
        }
    }
}
