/*
 * SPDX-FileCopyrightText: 2024 Slava Aseev <nullptrnine@basealt.ru>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

import QtQuick 2.15
import QtQuick.Controls 2.15 as QQC2
import QtQuick.Layouts 1.15

import org.kde.plasma.plasmoid 2.0
import org.kde.plasma.core 2.0 as PlasmaCore
import org.kde.kirigami 2.15 as Kirigami

Kirigami.FormLayout {
    id: weatherAppearanceConfigPage

    property alias cfg_tempBadgeScale: tempBadgeScaleSpinBox.value
    property alias cfg_showBackgroundOnTempBadge: showBackgroundOnTempBadgeCheckBox.checked
    property alias cfg_showLabelsInToolTip: showLabelsInToolTipCheckBox.checked
    property alias cfg_showCondTempInToolTip: showCondTempInToolTipCheckBox.checked
    property alias cfg_showWindInToolTip: showWindInToolTipCheckBox.checked
    property alias cfg_showPressureInToolTip: showPressureInToolTipCheckBox.checked
    property alias cfg_showHumidityInToolTip: showHumidityInToolTipCheckBox.checked

    function showBadgeSettings() {
        return Plasmoid.formFactor == PlasmaCore.Types.Vertical || ((Plasmoid.containmentType & PlasmaCore.Types.CustomEmbeddedContainment) |
               (Plasmoid.containmentDisplayHints & PlasmaCore.Types.ContainmentForcesSquarePlasmoids));
    }

    QQC2.CheckBox {
        id: showBackgroundOnTempBadgeCheckBox
        visible: showBadgeSettings()
        Kirigami.FormData.label: i18nc("@option:check", "Show background on temperature badge:")
    }

    QQC2.SpinBox {
        id: tempBadgeScaleSpinBox
        visible: showBadgeSettings();

        from: 70
        to: 150
        stepSize: 10
        editable: true

        Kirigami.FormData.label: i18nc("@label:spinbox", "Temperature badge scale:")

        textFromValue: function(value) {
            return (i18nc("badge scale", "%1%", value));
        }
        valueFromText: function(text) {
            return parseInt(text);
        }
    }

    Item {
        visible: showBadgeSettings();
        Kirigami.FormData.isSection: true
    }

    QQC2.CheckBox {
        id: showCondTempInToolTipCheckBox
        Kirigami.FormData.label: i18nc("@label", "Show in tooltip:")
        text: i18nc("@option:check", "Condition and temperature")
    }

    QQC2.CheckBox {
        id: showWindInToolTipCheckBox
        text: i18nc("@option:check Show in tooltip: wind", "Wind")
    }

    QQC2.CheckBox {
        id: showPressureInToolTipCheckBox
        text: i18nc("@option:check Show in tooltip: pressure", "Pressure")
    }

    QQC2.CheckBox {
        id: showHumidityInToolTipCheckBox
        text: i18nc("@option:check Show in tooltip: humidity", "Humidity")
    }

    QQC2.CheckBox {
        id: showLabelsInToolTipCheckBox
        text: i18nc("@option:check Show in tooltip: labels", "Item labels")
    }
}
